@@ -15,7 +15,7 @@ use Try::Tiny;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 
 sub serve_static_file {
@@ -27,6 +27,13 @@ sub serve_static_file {
 
     try {
 
+        # Ideally we could let the file open fail when a file does not exist, but this seems to cause the process to
+        # exit in a way that try/catch cannot handle on some systems.  We can risk a potential race condition where the
+        # file disappears between the existence check and opening: the worst case is that it would have the same effect
+        # as not checking for file existence.
+
+        die "No such file or directory" unless -e $abs;
+
         my $fh = IO::File->new( $abs, "r" ) or die $!;
 
         binmode($fh);
@@ -68,7 +75,7 @@ Catalyst::Plugin::Static::File - Serve a specific static file
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
